.. AUTO-GENERATED FILE -- DO NOT EDIT!

core.version
============

Module: :mod:`core.version`
---------------------------
.. automodule:: zmq.core.version

.. currentmodule:: zmq.core.version

Functions
---------


.. autofunction:: zmq.core.version.pyzmq_version


.. autofunction:: zmq.core.version.zmq_version

